----------------------
--   Complexation   --
----------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity DsRed_MS2_L7Ae_comp is
generic (kp1 : real := 0.3;
		 km1 : real := 0.1;
		 kdegr : real := 0.1);
port (terminal CDbox_MS2box_DsRed_term : CDbox_MS2box_DsRed;
terminal L7Ae_term : L7Ae;
terminal MS2_term : MS2;

terminal Comp_term : DsRed_MS2_L7Ae);
end;

architecture conservative of DsRed_MS2_L7Ae_comp is

	constant valr_pro1,valr_pro2 :real := 10.0;

quantity C_CDbox_MS2box_DsRed across CDbox_MS2box_DsRed_cell to CDbox_MS2box_DsRed_term;
quantity C_L7Ae across L7Ae_cell to L7Ae_term;
quantity C_MS2 across MS2_cell to MS2_term;


	quantity Ccomp across Fcomp through DsRed_MS2_L7Ae_cell to Comp_term;
		
Begin

	r_CDbox_MS2box_DsRed : entity rescomp_CDbox_MS2box_DsRed(conservative)
			 generic map (10.0)
			 port map (a => CDbox_MS2box_DsRed_term, b => CDbox_MS2box_DsRed_cell, Comp_L7Ae => L7Ae_term, Comp_MS2 => MS2_term);
	r_L7Ae : entity rescomp_L7Ae_2(conservative)
			 generic map (1.0)
			 port map (a => L7Ae_term, b => L7Ae_cell, Comp_CDbox_MS2box_DsRed => CDbox_MS2box_DsRed_term, Comp_MS2 => MS2_term);
	r_MS2 : entity rescomp_MS2_2(conservative)
			 generic map (1.0)
			 port map (a => MS2_term, b => MS2_cell, Comp_CDbox_MS2box_DsRed => CDbox_MS2box_DsRed_term, Comp_L7Ae => L7Ae_term);


	r_comp1 : entity DsRed_MS2_L7Ae_resistor(conservative)
			  generic map (1.0/km1)
			  port map (a => Comp_term, b => DsRed_MS2_L7Ae_cell);
	r_comp2 : entity DsRed_MS2_L7Ae_resistor(conservative)
			  generic map (1.0/kdegr)
			  port map (a => Comp_term, b => DsRed_MS2_L7Ae_cell);

Fcomp == kp1*C_CDbox_MS2box_DsRed*C_L7Ae*C_MS2;

end;

