----------------------
--   Complexation   --
----------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity d2EYFP_L7Ae_comp is
generic (kp1 : real := 0.9;
		 km1 : real := 0.1;
		 kdegr : real := 0.5);
port (terminal CDbox_d2EYFP_term : CDbox_d2EYFP;
terminal L7Ae_term : L7Ae;

terminal Comp_term : d2EYFP_L7Ae);
end;

architecture conservative of d2EYFP_L7Ae_comp is

	constant valr_pro1,valr_pro2 :real := 10.0;

quantity C_CDbox_d2EYFP across CDbox_d2EYFP_cell to CDbox_d2EYFP_term;
quantity C_L7Ae across L7Ae_cell to L7Ae_term;


	quantity Ccomp across Fcomp through d2EYFP_L7Ae_cell to Comp_term;
		
Begin

	r_CDbox_d2EYFP : entity rescomp_CDbox_d2EYFP(conservative)
			 generic map (10.0)
			 port map (a => CDbox_d2EYFP_term, b => CDbox_d2EYFP_cell, Comp_L7Ae => L7Ae_term);
	r_L7Ae : entity rescomp_L7Ae(conservative)
			 generic map (1.0)
			 port map (a => L7Ae_term, b => L7Ae_cell, Comp_CDbox_d2EYFP => CDbox_d2EYFP_term);


	r_comp1 : entity d2EYFP_L7Ae_resistor(conservative)
			  generic map (1.0/km1)
			  port map (a => Comp_term, b => d2EYFP_L7Ae_cell);
	r_comp2 : entity d2EYFP_L7Ae_resistor(conservative)
			  generic map (1.0/kdegr)
			  port map (a => Comp_term, b => d2EYFP_L7Ae_cell);

Fcomp == kp1*C_CDbox_d2EYFP*C_L7Ae;

end;

