----------------------
--   Complexation   --
----------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity d2EYFP_MS2_comp is
generic (kp1 : real := 0.9;
		 km1 : real := 0.1;
		 kdegr : real := 0.5);
port (terminal MS2_term : MS2;
terminal MS2box_d2EYFP_term : MS2box_d2EYFP;

terminal Comp_term : d2EYFP_MS2);
end;

architecture conservative of d2EYFP_MS2_comp is

	constant valr_pro1,valr_pro2 :real := 10.0;

quantity C_MS2 across MS2_cell to MS2_term;
quantity C_MS2box_d2EYFP across MS2box_d2EYFP_cell to MS2box_d2EYFP_term;


	quantity Ccomp across Fcomp through d2EYFP_MS2_cell to Comp_term;
		
Begin

	r_MS2 : entity rescomp_MS2(conservative)
			 generic map (1.0)
			 port map (a => MS2_term, b => MS2_cell, Comp_MS2box_d2EYFP => MS2box_d2EYFP_term);
	r_MS2box_d2EYFP : entity rescomp_MS2box_d2EYFP(conservative)
			 generic map (10.0)
			 port map (a => MS2box_d2EYFP_term, b => MS2box_d2EYFP_cell, Comp_MS2 => MS2_term);


	r_comp1 : entity d2EYFP_MS2_resistor(conservative)
			  generic map (1.0/km1)
			  port map (a => Comp_term, b => d2EYFP_MS2_cell);
	r_comp2 : entity d2EYFP_MS2_resistor(conservative)
			  generic map (1.0/kdegr)
			  port map (a => Comp_term, b => d2EYFP_MS2_cell);

Fcomp == kp1*C_MS2*C_MS2box_d2EYFP;

end;

